summaryrefslogtreecommitdiffstats
path: root/tdm/kfrontend/themer
diff options
context:
space:
mode:
Diffstat (limited to 'tdm/kfrontend/themer')
-rw-r--r--tdm/kfrontend/themer/tdmitem.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/tdm/kfrontend/themer/tdmitem.cpp b/tdm/kfrontend/themer/tdmitem.cpp
index fb695462c..13969c4bf 100644
--- a/tdm/kfrontend/themer/tdmitem.cpp
+++ b/tdm/kfrontend/themer/tdmitem.cpp
@@ -290,12 +290,12 @@ KdmItem::paint( TQPainter *p, const TQRect &rect )
return;
if (myWidget || (myLayoutItem && myLayoutItem->widget())) {
// KListView because it's missing a Q_OBJECT'
// FIXME: This is a nice idea in theory, but in practice it is
// very confusing for the user not to see the empty list box
// delineated from the rest of the greeter.
// Maybe set a darker version of the background instead of an exact copy?
- if ( myWidget && myWidget->isA( "KListView" ) ) {
+ if ( myWidget && myWidget->isA( "TDEListView" ) ) {
if ((_compositor.isEmpty()) || (!argb_visual_available)) {
// Software blend only (no compositing support)
TQPixmap copy( myWidget->size() );
@@ -290,12 +290,12 @@ KdmItem::paint( TQPainter *p, const TQRect &rect )
return;
if (myWidget || (myLayoutItem && myLayoutItem->widget())) {
- // KListView because it's missing a Q_OBJECT'
+ // TDEListView because it's missing a Q_OBJECT'
// FIXME: This is a nice idea in theory, but in practice it is
// very confusing for the user not to see the empty list box